==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/players/gstreamer/gstplayerconfigwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "gstplayerconfigwidget.h"
#include "gstplayerconfigdefs.h"

#include <qlayout.h>
#include <qgroupbox.h>
#include <qcheckbox.h>

#include <klocale.h>
#include <kcombobox.h>

using namespace SubtitleComposer;

GstPlayerConfigWidget::GstPlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	AppConfigGroupWidget( configGroup, parent )
{
	QGroupBox* audioGroupBox = createGroupBox( i18n( "Audio" ) );

	m_audioSinkCheckBox = new QCheckBox( audioGroupBox );
	m_audioSinkCheckBox->setText( i18n( "Audio sink" ) );

	m_audioSinkComboBox = new KComboBox( false, audioGroupBox );
	m_audioSinkComboBox->setEnabled( false );
	m_audioSinkComboBox->setEditable( true );
	m_audioSinkComboBox->insertStringList( QStringList::split( ' ', "autoaudiosink alsasink osssink esdsink gconfaudiosink pulsesink fakesink" ) );


	QGroupBox* videoGroupBox = createGroupBox( i18n( "Video" ) );

	m_videoSinkCheckBox = new QCheckBox( videoGroupBox );
	m_videoSinkCheckBox->setText( i18n( "Video sink" ) );

	m_videoSinkComboBox = new KComboBox( false, videoGroupBox );
	m_videoSinkComboBox->setEnabled( false );
	m_videoSinkComboBox->setEditable( true );
	m_videoSinkComboBox->insertStringList( QStringList::split( ' ', "autovideosink ximagesink xvimagesink gconfvideosink fakesink" ) );

	QGridLayout* audioLayout = createGridLayout( audioGroupBox );
	audioLayout->addWidget( m_audioSinkCheckBox, 0, 0 );
	audioLayout->addWidget( m_audioSinkComboBox, 0, 1 );

	QGridLayout* videoLayout = createGridLayout( videoGroupBox );
	videoLayout->addWidget( m_videoSinkCheckBox, 0, 0 );
	videoLayout->addWidget( m_videoSinkComboBox, 0, 1 );

	connect( m_audioSinkCheckBox, SIGNAL( toggled(bool) ), m_audioSinkComboBox, SLOT( setEnabled(bool) ) );
	connect( m_videoSinkCheckBox, SIGNAL( toggled(bool) ), m_videoSinkComboBox, SLOT( setEnabled(bool) ) );
	connect( m_audioSinkCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoSinkCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_audioSinkComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoSinkComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );

	setControlsFromConfig();
}

GstPlayerConfigWidget::~GstPlayerConfigWidget()
{
}

void GstPlayerConfigWidget::setConfigFromControls()
{
	m_configGroup.setOption(
		OPT_AUDIOSINK,
		m_audioSinkCheckBox->isChecked() ?
			m_audioSinkComboBox->currentText() :
			QString::null
	);

	m_configGroup.setOption(
		OPT_VIDEOSINK,
		m_videoSinkCheckBox->isChecked() ?
			m_videoSinkComboBox->currentText() :
			QString::null
	);
}

void GstPlayerConfigWidget::setControlsFromConfig()
{
	QString value = m_configGroup.option( OPT_AUDIOSINK );
	m_audioSinkCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_audioSinkComboBox->setEditText( value );

	value = m_configGroup.option( OPT_VIDEOSINK );
	m_videoSinkCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_videoSinkComboBox->setEditText( value );
}

#include "gstplayerconfigwidget.moc"

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/players/gstreamer/gstplayerconfigwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "gstplayerconfigwidget.h"
#include "gstplayerconfigdefs.h"

#include <qlayout.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>

#include <klocale.h>
#include <kcombobox.h>

using namespace SubtitleComposer;

GstPlayerConfigWidget::GstPlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	AppConfigGroupWidget( configGroup, parent )
{
	QButtonGroup* audioButtonGroup = createButtonGroup( i18n( "Audio" ) );

	m_audioSinkCheckBox = new QCheckBox( audioButtonGroup );
	m_audioSinkCheckBox->setText( i18n( "Audio sink" ) );

	m_audioSinkComboBox = new KComboBox( false, audioButtonGroup );
	m_audioSinkComboBox->setEnabled( false );
	m_audioSinkComboBox->setEditable( true );
	m_audioSinkComboBox->insertStringList( QStringList::split( ' ', "autoaudiosink alsasink osssink esdsink gconfaudiosink pulsesink fakesink" ) );


	QButtonGroup* videoButtonGroup = createButtonGroup( i18n( "Video" ) );

	m_videoSinkCheckBox = new QCheckBox( videoButtonGroup );
	m_videoSinkCheckBox->setText( i18n( "Video sink" ) );

	m_videoSinkComboBox = new KComboBox( false, videoButtonGroup );
	m_videoSinkComboBox->setEnabled( false );
	m_videoSinkComboBox->setEditable( true );
	m_videoSinkComboBox->insertStringList( QStringList::split( ' ', "autovideosink ximagesink xvimagesink gconfvideosink fakesink" ) );

	QGridLayout* audioLayout = createGridLayout( audioButtonGroup );
	audioLayout->addWidget( m_audioSinkCheckBox, 0, 0 );
	audioLayout->addWidget( m_audioSinkComboBox, 0, 1 );

	QGridLayout* videoLayout = createGridLayout( videoButtonGroup );
	videoLayout->addWidget( m_videoSinkCheckBox, 0, 0 );
	videoLayout->addWidget( m_videoSinkComboBox, 0, 1 );


	connect( m_audioSinkCheckBox, SIGNAL( toggled(bool) ), m_audioSinkComboBox, SLOT( setEnabled(bool) ) );
	connect( m_videoSinkCheckBox, SIGNAL( toggled(bool) ), m_videoSinkComboBox, SLOT( setEnabled(bool) ) );
	connect( m_audioSinkCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoSinkCheckBox, SIGNAL( toggled(bool) ), this, SIGNAL( settingsChanged() ) );
	connect( m_audioSinkComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );
	connect( m_videoSinkComboBox, SIGNAL( textChanged(const QString&) ), this, SIGNAL( settingsChanged() ) );

	setControlsFromConfig();
}

GstPlayerConfigWidget::~GstPlayerConfigWidget()
{
}

void GstPlayerConfigWidget::setConfigFromControls()
{
	m_configGroup.setOption(
		OPT_AUDIOSINK,
		m_audioSinkCheckBox->isChecked() ?
			m_audioSinkComboBox->currentText() :
			QString::null
	);

	m_configGroup.setOption(
		OPT_VIDEOSINK,
		m_videoSinkCheckBox->isChecked() ?
			m_videoSinkComboBox->currentText() :
			QString::null
	);
}

void GstPlayerConfigWidget::setControlsFromConfig()
{
	QString value = m_configGroup.option( OPT_AUDIOSINK );
	m_audioSinkCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_audioSinkComboBox->setEditText( value );

	value = m_configGroup.option( OPT_VIDEOSINK );
	m_videoSinkCheckBox->setChecked( ! value.isEmpty() );
	if ( ! value.isEmpty() )
		m_videoSinkComboBox->setEditText( value );
}

#include "gstplayerconfigwidget.moc"
